@@ -11,19 +11,19 @@
 #' Karim Lounici. 2012.
 #' @author Stephen R. Haptonstahl \email{srh@@haptonstahl.org}
 CovarianceWithMissing <- function(x) {
-  # Guardians
   stopifnot(methods::is(x, "matrix") | (methods::is(x, "data.frame") && is.numeric(as.matrix(x))))
   
-  delta <- mean(!is.na(x))
-  if( 0 == delta ) {
+  delta <- mean(!is.na(x))  # probabiliity a cell is observed, proportion of observed entries
+  if( 1 == delta ) {        # no missing data
     out <- stats::cov(x)
   } else {
+    # set up for notation of Louncini (2012)
     x <- as.matrix(x)
-    x <- t(x)  # puts observations in columns to fit notation of Louncini (2012)
+    x <- t(x)  # puts observations in columns, variables in rows
     n <- ncol(x)  # number of observations
     p <- nrow(x)  # number of variables
     
-    # perform the function
+    # per page 1 of the article
     y <- sweep(x, 1, rowMeans(x, na.rm=TRUE))
     y[is.na(y)] <- 0
     
